<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Υπάρχει ζωή έξω από τον φυλλομετρητή!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Έκδοση %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Αδειοδοτημένο στον/ην: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>Το %1 είναι Ελεύθερο Λογισμικό αλλά η ανάπτυξη του παίρνει πολύτιμο χρόνο.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Παρακαλούμε &lt;a href=&apos;%1%&apos;&gt;κάνετε μια δωρεά&lt;/a&gt; για να υποστηρίξετε την συνεχόμενη ανάπτυξη του %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Μεταφράστε το %1 στη γλώσσα σας με χρήση του %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Σχεδιασμός εικονιδίου από %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Έκδοση υπό τους όρους της &lt;a href=&apos;%1&apos;&gt;Γενικής Άδειας Χρήσης GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Εισάγετε τις λεπτομέρειες της άδειας χρήσης</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Ηλ. αλληλογραφία:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Κωδικός:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Παρακαλώ αποκτήστε την άδεια χρήσης του %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Αυτή η δοκιμαστική έκδοση έληξε.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Η πλήρης έκδοση σας επιτρέπει να παρακολουθήσετε βίντεο χωρίς διακοπές.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Χωρίς την άδεια χρήσης, η εφαρμογή θα λήξη σε %1 ημέρες.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Αγοράζοντας την πλήρη έκδοση, υποστηρίζετε επίσης την σκληρή δουλειά που έχω κάνει για τη δημιουργία του %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Χρήση της δοκιμαστικής έκδοσης</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Εισαγωγή άδειας χρήσης</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Αγορά άδειας χρήσης</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Λήψη</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Από %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Όλα τα βίντεο</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Μη ιδωμένα βίντεο</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Τελευταία ενημερωμένα</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Τελευταία προστιθέμενα</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Τελευταία ιδωμένα</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Περισσότερο ιδωμένα</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ταξινόμηση κατά</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Σημείωση όλων ως παρακολούθεντα</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Εμφάνιση ενημερωμένων</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Δεν έχετε συνδρομές. Χρησιμοποιήστε το αστέρι για να κάνετε συνδρομή σε κανάλια.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Όλα τα βίντεο</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Μη ιδωμένα βίντεο</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Σήμανση ως ιδωμένο</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Κατάργηση εγγραφής</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Δεν υπάρχουν ενημερωμένες συδρομές αυτήν την στιγμή.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Μόλις τώρα</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 προβολές</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>byte</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>byte/δευτ</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/δευτ</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/δευτ</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>δευτερόλεπτα</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>λεπτά</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>απομένουν %4 %5</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 λήφθηκε σε %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Η λήψη ολοκληρώθηκε</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Αλλάξτε τοποθεσία...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Επιλέξτε την τοποθεσία λήψης</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Η τοποθεσία λήψης άλλαξε.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Τα ήδη ληφθέντα θα παραμείνουν στην προηγούμενη τοποθεσία.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Λήψη στο: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Λήψεις</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Το εκτελέσιμο αρχείο έχει κακοποιηθεί, ίσως πρόκειται για ιό.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>Το %1 δεν θα εκτελεσθεί. Δοκιμάστε να το εγκαταστήσετε εκ νέου.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Έξοδος</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Επανεγκατάσταση</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Αναπαραγωγή</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Παύση</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Αναπαραγωγή/Παύση</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Διακοπή</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Διακοπή αναπαραγωγής μετά το τρέχον κομμάτι</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Επόμενο κομμάτι</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Προηγούμενο κομμάτι</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Αύξηση έντασης</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Μείωση έντασης</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Σίγαση</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Αναζήτηση μπροστά</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Αναζήτηση πίσω</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Αναζήτηση</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Εύρεση βίντεο και καναλιών μέσω λέξεις-κλειδιά </translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Περίηγηση</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Περιήγηση βίντεο ανά κατηγορία</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Συνδρομές</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Συνδρομές σε κανάλια</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Βολευτείτε</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Παράθυρο</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Ελαχιστοποίηση</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Διακοπή</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Διακοπή αναπαραγωγής και επιστροφή στη προβολή αναζήτησης</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>Π&amp;ροηγούμενο</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Επιστροφή στο προηγούμενο κομμάτι</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Παράλειψη</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Μετάβαση στο επόμενο βίντεο</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Α&amp;ναπαραγωγή</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Συνέχεια αναπαραγωγής</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Πλήρης οθόνη</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Προβολή σε πλήρη οθόνη</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Συμπαγής εμφάνιση</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Απόκρυψη της λίστας αναπαραγωγής και της εργαλειοθήκης</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Άνοιγμα στην Ιστοσελίδα του &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Μετάβαση στη σελίδα βίντεο του YouTube και παύση αναπαραγωγής</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Αντιγραφή του &amp;συνδέσμου YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Αντιγραφή του συνδέσμου του τρέχοντος βίντεο YouTube στο πρόχειρο</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Αντιγραφή του &amp;συνδέσμου της ροής βίντεο</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Αντιγραφή του συνδέσμου της τρέχουσας ροής βίντεο στη μνήμη</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Αναζήτηση των &amp;επεισοδίων του βίντεο</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Εύρεση των υπόλοιπων επισοδείων του βίντεο, ελπίζουμε στη σωστή σειρά</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Αφαίρεση</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Αφαίρεση επιλεγμένων βίντεο απο την λίστα αναπαραγωγής</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Μετακίνηση προς τα &amp;πάνω</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Μετακίνηση επιλεγμένων βίντεο προς τα πάνω</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Μετακίνηση προς τα &amp;κάτω</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Μετακίνηση επιλεγμένων βίντεο προς τα κάτω</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Εκκαθάριση πρόσφατων αναζητήσεων</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Εκκαθάριση του ιστορικού αναζήτησης. Αυτή η ενέργεια δε μπορεί να αναιρεθεί.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Έ&amp;ξοδος</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Αντίο</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Ιστοχώρος</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>Το %1 στο διαδίκτυο</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Κάντε μια &amp;δωρεά</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Παρακαλούμε υποστηρίξτε την συνεχόμενη ανάπτυξη του %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Σχετικά</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Πληροφορίες για το %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Αναζήτηση</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Σίγαση ήχου</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Εκκίνηση της αναπαραγωγής &amp;χειροκίνητα</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Εκκίνηση αναπαραγωγής των βίντεο χειροκίνητα</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Λήψεις</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Εμφάνιση λεπτομερειών για τις λήψεις βίντεο</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Λήψη</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Λήψη του τρέχοντος βίντεο</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Λήψη &amp;στιγμιότυπου</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Εγγραφή στο κανάλι</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Κοινοποίηση του τρέχοντος βίντεο μέσω %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Ηλ. αλληλογραφία</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Ηλ. αλληλογραφία</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Διατήρηση στην κορυφή</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Διακοπή μετά από αυτό το βίντεο</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Αναφέρετε σφάλμα...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Σύνθετη αναζήτηση...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Περισσότερα...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Σχετικά βίντεο</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Παρακολουθήστε βίντεο που σχετίζονται με το τρέχον</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Άνοιγμα σε &amp;Περιηγητή...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Λατρεύετε το %1; Βαθμολογήστε το!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Αγοράστε το %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Εφαρμογή</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Αναπαραγωγή</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Λ&amp;ίστα αναπαραγωγής</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>Βίν&amp;τεο</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Κοινοποίηση</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Προβολή</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Πατήστε %1 για να αυξήσετε την ένταση, %2 για να την χαμηλώσετε</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Επιλέξτε την τοποθεσία για το περιεχόμενό σας </translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Άνοιγμα %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Θέλετε να κλείσετε το %1 ενώ βρίσκεται μια λήψη σε εξέλιξη;</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Αν κλείσετε το %1 τώρα, η λήψη θα ακυρωθεί.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Κλείσιμο και ακύρωση λήψης</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Αναμονή ολοκλήρωσης λήψης</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Σφάλμα: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Παύση</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Παύση αναπαραγωγής</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Φόρτωση...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Έξοδος από &amp;πλήρη οθόνη</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Υπολειπόμενος χρόνος: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Ένταση στο %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Σίγαση</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Η ένταση αποκαταστάθηκε</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>H μέγιστη ανάλυση βίντεο τέθηκε σε %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Η ιδιωτικότητα σας είναι τώρα ασφαλής</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Οι λήψεις ολοκληρώθηκαν</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>Η έκδοση %2 του %1 έχει γίνει διαθέσιμη.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Υπενθύμιση αργότερα</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Ενημέρωση</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Τώρα μπορείτε να επικολλήσετε τον συνδεσμό του YouTube σε κάποια άλλη εφαρμογή</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Τώρα μπορείτε να επικολλήσετε τον σύνδεσμο της ροής βίντεο σε κάποια άλλη εφαρμογή</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Ο σύνδεσμος θα είναι έγκυρος για περιορισμένο χρονικό διάστημα.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Λήψη %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>από</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>μέρος</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>επεισόδιο</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Αποστολή από %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Κατάργηση εγγραφής στο %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Εγγραφή στο %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Διεγράφη από το %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Εγγραφή στο %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Μια νέα έκδοση του %1 είναι διαθέσιμη!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>Η %1 %2 είναι διαθέσιμη. Έχετε την %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Θα θέλατε να την κατεβάσετε τώρα;</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Παράλειψη αυτής της έκδοσης</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Υπενθύμισε το μου αργότερα</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Εγκατάσταση ενημέρωσης</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Επικόλληση</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 από %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Προετοιμάζεται</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Απέτυχε</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Ολοκληρώθηκε</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Διακόπηκε</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Διακοπή λήψης</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Εμφάνιση σε %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Άνοιγμα γονικού φακέλου</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Επανεκκίνηση λήψης</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Εμφάνιση %1 ακόμα</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Κανένα βίντεο</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Δεν υπάρχουν άλλα βίντεο</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Ταξινόμηση κατά ...</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Σχετικότητα</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Ημερομηνία</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Αριθμό προβολών</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Βαθμολογία</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Οποτεδήποτε</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Σήμερα</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>Εβδομάδα</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>Μήνας</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Διάρκεια</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Όλα</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Μικρή</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Μέτρια</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Μεγάλη</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Λιγότερη από 4 λεπτά</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Μεταξύ 4 και 20 λεπτά</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Μεγαλύτερη από 20 λεπτά</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Ποιότητα</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Υψηλή Ανάλυση</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p και μεγαλύτερη</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Έγινε</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Έγινε</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Αναζήτηση</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Καλωσορίσατε στο &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>για να αρχίσετε να βλέπετε βίντεο.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>μια λέξη-κλειδί</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Εισάγετε</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Πρόσφατες λέξεις-κλειδιά</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Πρόσφατα κανάλια</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Αποκτήστε την πλήρη έκδοση</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Επιστροφή</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Προώθηση σε %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Επιστροφή στο %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Σύνθετη Αναζήτηση</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Μήπως εννοείτε: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Αλλάξτε τοποθεσία...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Το στιγμιότυπο αποθηκεύτηκε σε %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Η τοποθεσία για στιγμιότυπα άλλαξε.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Πιο δημοφιλή</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Λήψη ενημερώσεων...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Λήψη %1...</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Αλγερία</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Αργεντινή</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Αυστραλία</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Βέλγιο</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Βραζιλία</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Καναδάς</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Χιλή</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Κολομβία</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Τσεχία</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Αίγυπτος</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Γαλλία</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Γερμανία</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Γκάνα</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Ελλάδα</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Χονγκ Κονγκ</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Ουγγαρία</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Ινδία</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Ινδονησία</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Ιρλανδία</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Ισραήλ</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Ιταλία</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Ιαπωνία</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Ιορδανία</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Κένυα</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Μαλαισία</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Μεξικό</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Μαρόκο</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Κάτω Χώρες</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Νέα Ζηλανδία</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Νιγηρία</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Περού</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Φιλιππίνες</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Πολωνία</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Ρωσία</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Σαουδική Αραβία</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Σινγκαπούρη</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Νότια Αφρική</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Νότια Κορέα</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Ισπανία</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Σουηδία</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Ταϊβάν</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Τυνησία</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Τουρκία</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Ουγκάντα</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Ηνωμένα Αραβικά Εμιράτα</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Ηνωμένο Βασίλειο</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Υεμένη</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Παγκοσμίως</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Αδυναμία λήψης της ροής βίντεο για το %1</translation>
    </message>
</context>
</TS>